@@ -5,14 +5,15 @@ from contextlib import AsyncExitStack
 from types import TracebackType
 
 from anyio import create_task_group
-from wiredb import Provider, ClientWire as _ClientWire
+from pycrdt import Doc
+from wiredb import ClientWire as _ClientWire
 
 from .server_wire import STOP, Pipe
 
 
 class ClientWire(_ClientWire):
-    def __init__(self, id: str, *, connection) -> None:
-        super().__init__()
+    def __init__(self, id: str, doc: Doc | None = None, auto_update: bool = True, *, connection) -> None:
+        super().__init__(doc, auto_update)
         self._id = id
         self._sender, self._receiver, self._self_sender = connection
 
@@ -20,8 +21,9 @@ class ClientWire(_ClientWire):
         async with AsyncExitStack() as exit_stack:
             tg = await exit_stack.enter_async_context(create_task_group())
             self.channel = Pipe(tg, self._sender, self._receiver, self._id)
-            await exit_stack.enter_async_context(Provider(self._doc, self.channel))
-            self._exit_stack = exit_stack.pop_all()
+            await super().__aenter__()
+            exit_stack.push_async_exit(super().__aexit__)
+            self._exit_stack0 = exit_stack.pop_all()
         return self
 
     async def __aexit__(
@@ -34,4 +36,4 @@ class ClientWire(_ClientWire):
             os.fdopen(self._self_sender, "wb", buffering=0).write(STOP)
         except BaseException:  # pragma: nocover
             pass
-        return await self._exit_stack.__aexit__(exc_type, exc_val, exc_tb)
+        return await self._exit_stack0.__aexit__(exc_type, exc_val, exc_tb)
